nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Wwdt

Struct Wwdt 

pub struct Wwdt { /* private fields */ }
Windowed Watchdog Timer (WWDT)

Implementations

Source

impl Wwdt

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn mod_(self) -> Reg<Mod, RW>

Watchdog mode register. This register contains the basic mode and status of the Watchdog Timer.

pub const fn tc(self) -> Reg<Tc, RW>

Watchdog timer constant register. This 24-bit register determines the time-out value.

pub const fn feed(self) -> Reg<Feed, W>

Watchdog feed sequence register. Writing 0xAA followed by 0x55 to this register reloads the Watchdog timer with the value contained in TC.

pub const fn tv(self) -> Reg<Tv, R>

Watchdog timer value register. This 24-bit register reads out the current value of the Watchdog timer.

pub const fn warnint(self) -> Reg<Warnint, RW>

Watchdog Warning Interrupt compare value.

pub const fn window(self) -> Reg<Window, RW>

Watchdog Window compare value.